=================
Python Client API
=================

slicer\_package\_manager\_client package
========================================

.. automodule:: slicer_package_manager_client
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

slicer\_package\_manager\_client.cli module
-------------------------------------------

.. automodule:: slicer_package_manager_client.cli
   :members:
   :undoc-members:
   :show-inheritance:
